@@ -15,6 +15,7 @@ from Acquisition import aq_parent
 from zope.interface import classImplements
 from DateTime import DateTime
 from ZPublisher.HTTPRequest import FileUpload
+from ZODB.POSException import ConflictError
 try:
     # 3.0+
     from zope.contenttype import guess_content_type
@@ -542,7 +543,7 @@ class GetPaidPFGSalesforceAdapter(SalesforcePFGAdapter):
 
         fixedRows.append(FixedRow(keyColumn="form_field",
                                   initialData={"form_field" : "Shipping Cost", 
-                                               "field_path" : "getShippingCost",
+                                               "field_path" : "shipping_cost",
                                                "sf_field" : ""}))
 
         return fixedRows
@@ -647,11 +648,17 @@ def handleOrderWorkflowTransition( order, event ):
 
                 try:
                     executeAdapter(order, data, salesforce)
+                except ConflictError:
+                    raise
                 except Exception, e:
-                    # I catch everything since any uncaught exception here 
+                    # I catch everything since any uncaught exception here
                     # will prevent the order from moving to charged
                     logger.error("Exception saving order %s to salesforce: %s" % (order.order_id, e))
                     logger.info('Data: %s' % data)
+                except:
+                    logger.error("Unknown Exception saving order %s to salesforce" % (order.order_id))
+                    logger.info('Data: %s' % data)
+
 
 def executeAdapter(order, data, salesforce):
     sfObject = data['SFObjectForCustomer']
